@@ -7,6 +7,7 @@ from . import utils as ut
 from functools import reduce, lru_cache
 from sympy.physics.wigner import wigner_3j, wigner_6j
 
+
 @lru_cache(maxsize=None)
 def recursive_a(k, q, m):
     """
@@ -262,7 +263,8 @@ def calc_HCF(J, CFPs, stev_ops, k_max=False, oef=False):
                                       q_ind = 1, .. 2*q_max + 5 :(q_max=+-k)
 
     Keyword arguments:
-        k_max (int)    : Maximum value of k to use in summation - by default 2*J
+        k_max (int)    : Maximum value of k to use in summation - by default
+                         2*J
         oef (np.array) : Operator equivalent factors for each CFP
                          i.e. 27 CFPs = 27 OEFs
                          by default these are set to unity
@@ -623,15 +625,19 @@ def barrier_figure(J, energies, Jz_expect, trans=False, ax_in=False,
         linewidth=0,
         color=state_colour,
         label=levels_name
-        )
+    )
 
     # Plot transition arrows
     if isinstance(trans, np.ndarray):
 
         # Evolve transition matrix and find allowed transitions
-        output_trans, num_trans = _evolve_trans_mat(J, Jz_expect, trans,
-                                                    allowed_trans=allowed_trans,
-                                                    normalise=normalise_trans)
+        output_trans, num_trans = _evolve_trans_mat(
+            J,
+            Jz_expect,
+            trans,
+            allowed_trans=allowed_trans,
+            normalise=normalise_trans
+        )
 
         np.savetxt("inputtrans.dat", trans)
         np.savetxt("outputtrans.dat", output_trans)
@@ -644,18 +650,20 @@ def barrier_figure(J, energies, Jz_expect, trans=False, ax_in=False,
 
         # Difference between initial and final <Jz>
         Jz_expect_diff = [
-                          Jz_expect[output_trans[row][0]]-Jz_expect[output_trans[row][1]]
-                          for row in range(num_trans)
-                         ]
+            Jz_expect[output_trans[row][0]]-Jz_expect[output_trans[row][1]]
+            for row in range(num_trans)
+        ]
 
         # Final energies
-        energies_final = [energies[output_trans[row][1]] for row in range(num_trans)]
+        energies_final = [
+            energies[output_trans[row][1]] for row in range(num_trans)
+        ]
 
         # Difference between initial and final energies
         energies_diff = [
-                         energies[output_trans[row][0]] - energies[output_trans[row][1]]
-                         for row in range(num_trans)
-                        ]
+            energies[output_trans[row][0]] - energies[output_trans[row][1]]
+            for row in range(num_trans)
+        ]
 
         # Alpha channel values
         alphas = [output_trans[row][2] for row in range(num_trans)]
@@ -671,15 +679,15 @@ def barrier_figure(J, energies, Jz_expect, trans=False, ax_in=False,
 
         # Draw lines between levels
         ax.quiver(
-                  Jz_expect_final,
-                  energies_final,
-                  Jz_expect_diff,
-                  energies_diff,
-                  scale_units='xy',
-                  angles='xy',
-                  scale=1,
-                  color=t_rgba_colors
-                )
+            Jz_expect_final,
+            energies_final,
+            Jz_expect_diff,
+            energies_diff,
+            scale_units='xy',
+            angles='xy',
+            scale=1,
+            color=t_rgba_colors
+        )
 
     # Set x axis options
     ax.set_xlabel(xlabel)
@@ -694,9 +702,9 @@ def barrier_figure(J, energies, Jz_expect, trans=False, ax_in=False,
     if yax2:
         ax2.set_ylabel(yax2_label)
         ax2.set_ylim(
-                     ax.get_ylim()[0] * yax2_conv,
-                     ax.get_ylim()[1] * yax2_conv
-                    )
+            ax.get_ylim()[0] * yax2_conv,
+            ax.get_ylim()[1] * yax2_conv
+        )
         ax2.yaxis.set_major_locator(plt.MaxNLocator(7))
 
     # Set axis limits
@@ -772,6 +780,6 @@ def hunds_ground_term(n_elec, n_orb):
     elif n_elec == n_orb:
         s = max_s
         l = 0.
-        j  = 0.
+        j = 0.
 
     return j, l, s
