@@ -8,8 +8,7 @@ if __name__ == "__main__":
 
     k_max = 6
     j = 7.5
-    n = 9
-    
+
     jx, jy, jz, jp, jm, j2 = me.calc_ang_mom_ops(j)
 
     okq = me.calc_stev_ops(k_max, j, jp, jm, jz)
@@ -21,5 +20,3 @@ if __name__ == "__main__":
     jz_expect = np.diag(np.real(la.inv(cf_vec) @ jz @ cf_vec))
 
     fig, axes = me.barrier_figure(j, cf_val, jz_expect, show=True, yax2=True)
-
-    print(me.calc_oef(n, J, L, S))
